import { rootPath } from "./path.config";
export interface ConfigInfo {
    /**
     * 组件系列前缀
     */
    series: string;
    /**
     * 组件源码路径
     */
    src: string;
    /**
     * 组件配置
     */
    component: {
        /**
         * 组件的目录
         */
        dir: string;
        /**
         * 组件的模板文件路径
         */
        templateFilePath: string;
        /**
         * 组件的文件名
         */
        fileName: string;
        /**
         * 组件的入口模板
         */
        entryTemplate: string;
        /**
         * 组件的入口路径
         */
        entryPath: string;
    };
    /**
     * 样式配置
     */
    style: {
        /**
         * 样式的目录
         */
        dir: string;
        /**
         * 样式的模板文件路径
         */
        templateFilePath: string;
        /**
         * 样式的文件名
         */
        fileName: string;
        /**
         * 样式的变量模板
         */
        varTemplate: string;
        /**
         * 样式的变量路径
         */
        varPath: string;
        /**
         * 样式的入口模板
         */
        entryTemplate: string;
        /**
         * 样式的入口路径
         */
        entryPath: string;
    };
    /**
     * 组件示例路径
     */
    srcExample: string;
    /**
     * 示例配置
     */
    example: {
        /**
         * 示例的目录
         */
        dir: string;
        /**
         * 示例的模板文件路径
         */
        templateFilePath: string;
        /**
         * 示例的文件名
         */
        fileName: string;
        /**
         * 示例的入口模板
         */
        entryTemplate: string;
        /**
         * 示例的入口路径
         */
        entryPath: string;
    };
}
type KeyJoin<T> = {
    [K in Extract<keyof T, string>]: T[K] extends string | boolean | number ? K : `${K}.${KeyJoin<T[K]>}`;
}[Extract<keyof T, string>];
export type ConfigInfoKey = KeyJoin<ConfigInfo>;
export interface ResolvedPaths {
    /**
     * 组件目录路径
     */
    componentDirPath: string;
    /**
     * 组件文件内容
     */
    componentFileContent: string;
    /**
     * 组件文件路径
     */
    componentFilePath: string;
    /**
     * 组件入口文件追加内容
     */
    componentEntryFileAddContent: string;
    /**
     * 组件入口文件路径
     */
    componentEntryFilePath: string;
    /**
     * 样式目录路径
     */
    styleDirPath: string;
    /**
     * 样式文件内容
     */
    styleFileContent: string;
    /**
     * 样式路径
     */
    styleFilePath: string;
    /**
     * 样式变量文件追加内容
     */
    styleVarFileAddContent: string;
    /**
     * 样式变量路径
     */
    styleVarFilePath: string;
    /**
     * 样式入口文件追加内容
     */
    styleEntryFileAddContent: string;
    /**
     * 样式入口路径
     */
    styleEntryFilePath: string;
    /**
     * 示例目录路径
     */
    exampleDirPath: string;
    /**
     * 示例文件内容
     */
    exampleFileContent: string;
    /**
     * 示例文件路径
     */
    exampleFilePath: string;
    /**
     * 示例入口文件追加内容
     */
    exampleEntryFileAddContent: string;
    /**
     * 示例入口路径
     */
    exampleEntryFilePath: string;
}
/**
 * 解析模板
 */
export declare const resolveTemplate: (config: ConfigInfo, params: {
    series: string;
    name: string;
    full: string;
    cls: string;
    dir: string;
    rootPath: string;
}, list: KeyJoin<ConfigInfo>[]) => ResolvedPaths;
export {};
